smartcard.wx.SimpleSCardApp.SimpleSCardApp

# ``smartcard`.`wx`.`SimpleSCardApp`.`SimpleSCardApp``

class documentation

`class SimpleSCardApp(wx.App):`

View In Hierarchy

The SimpleSCardApp class represents the smart card application. SimpleSCardApp is a subclass of wx.App.

Method | `__init__` | Constructor for simple smart card application.
Method | `OnInit` | Create and display application frame.
Instance Variable | `appicon` | Undocumented
Instance Variable | `appname` | Undocumented
Instance Variable | `apppanel` | Undocumented
Instance Variable | `appstyle` | Undocumented
Instance Variable | `frame` | Undocumented
Instance Variable | `pos` | Undocumented
Instance Variable | `size` | Undocumented

def __init__(self, appname='', apppanel=None, appstyle=TR_DEFAULT, appicon=None, pos=(-1, -1), size=(-1, -1)):

Constructor for simple smart card application.

Parameters
appname | the application name
apppanel | the application panel to display in the application frame
appstyle | a combination of the following styles (bitwise or |) TR_SMARTCARD: display a smartcard tree panel TR_READER: display a reader tree panel TB_SMARTCARD: display a smartcard toolbar TB_SMARTCARD: display a reader toolbar PANEL_APDUTRACER: display an APDU tracer panel default is TR_DEFAULT = TR_SMARTCARD
appicon | the application icon file; the default is no icon
pos | the application position as a (x,y) tupple; default is (-1,-1)
size | the application window size as a (x,y) tuple; default is (-1,-1) Example: `app = SimpleSCardApp( appname = 'A simple smartcard application', apppanel = testpanel.MyPanel, appstyle = TR_READER | TR_SMARTCARD, appicon = 'resources\mysmartcard.ico')`

def OnInit(self):

Create and display application frame.

appicon =

Undocumented

appname =

Undocumented

apppanel =

Undocumented

appstyle =

Undocumented

frame =

Undocumented

pos =

Undocumented

size =

Undocumented